/***********************************************
 * RICHARD: NAVBAR
 ***********************************************/
(function ($) {
	'use strict';

	var navbarMain = $('.vlt-navbar--main');
	var navbarHeight = navbarMain.outerHeight();
	var navbarMainOffset = 0;

	// fake navbar
	var navbarFake = $('<div class="vlt-fake-navbar">').hide();

	// fixed navbar
	function _fixed_navbar() {
		navbarMain.addClass('vlt-navbar--fixed');
		navbarFake.show();
		// add solid color
		if (
			navbarMain.hasClass('vlt-navbar--transparent') &&
			navbarMain.hasClass('vlt-navbar--sticky')
		) {
			navbarMain.addClass('vlt-navbar--solid');
		}
	}

	function _unfixed_navbar() {
		navbarMain.removeClass('vlt-navbar--fixed');
		navbarFake.hide();
		// remove solid color
		if (
			navbarMain.hasClass('vlt-navbar--transparent') &&
			navbarMain.hasClass('vlt-navbar--sticky')
		) {
			navbarMain.removeClass('vlt-navbar--solid');
		}
	}

	function _on_scroll_navbar() {
		if (PTJS.window.scrollTop() > navbarMainOffset) {
			_fixed_navbar();
		} else {
			_unfixed_navbar();
		}
	}

	if (navbarMain.hasClass('vlt-navbar--sticky')) {
		PTJS.window.on('scroll resize', _on_scroll_navbar);
		_on_scroll_navbar();
		// append fake navbar
		navbarMain.after(navbarFake);
		// fake navbar height after resize
		navbarFake.height(navbarHeight);
		PTJS.debounceResize(function () {
			navbarFake.height(navbarHeight);
		});
	}

})(jQuery);

/***********************************************
 * HEADER ASIDE
 ***********************************************/
(function ($) {
	'use strict';

	var menuAside = $('.vlt-aside-menu-wrapper ul.sf-menu'),
		menuOverlay = $('.vlt-aside-menu-overlay'),
		menuNavigation = $('.vlt-navbar-navigation ul.sf-menu'),
		menuToggle = $('.vlt-menu-burger'),
		onepageLinks = menuAside.filter('.sf-menu-onepage').find('a'),
		menuIsOpen = false;

	// check if plugin defined
	if (typeof $.fn.superfish !== 'undefined') {
		menuNavigation.superfish({
			popUpSelector: 'ul.sub-menu',
			delay: 0,
			speed: 300,
			speedOut: 300,
			cssArrows: false,
			animation: {
				opacity: 'show',
				marginTop: '0',
				visibility: 'visible'
			},
			animationOut: {
				opacity: 'hide',
				marginTop: '10px',
				visibility: 'hidden'
			}
		});
	}

	// check if plugin defined
	if (typeof $.fn.superclick !== 'undefined') {
		menuAside.superclick({
			delay: 300,
			cssArrows: false,
			animation: {
				opacity: 'show',
				height: 'show',
			},
			animationOut: {
				opacity: 'hide',
				height: 'hide',
			},
		});
	}

	function _open_menu() {
		menuOverlay.fadeIn(300);
		if (typeof anime !== 'undefined') {
			anime
				.timeline({
					easing: 'easeInOutQuad',
					delay: 0,
				})
				.add({
					targets: '.vlt-aside-menu-wrapper',
					duration: 600,
					translateX: ['100%', 0],
				})
				.add({
					targets: [
						'.vlt-aside-menu__socials',
						'.vlt-aside-menu__navigation',
						'.vlt-aside-menu__copyright',
					],
					duration: 500,
					delay: anime.stagger(150),
					translateY: [50, 0],
					opacity: [0, 1],
					loop: false,
				});
		}
		menuIsOpen = true;
	}

	function _close_menu() {
		menuOverlay.fadeOut(300);
		if (typeof anime !== 'undefined') {
			anime
				.timeline({
					easing: 'easeInOutQuad',
					delay: 0,
				})
				.add({
					targets: '.vlt-aside-menu-wrapper',
					duration: 400,
					translateX: [0, '100%'],
				})
				.add({
					targets: [
						'.vlt-aside-menu__navigation',
						'.vlt-aside-menu__socials',
						'.vlt-aside-menu__copyright',
					],
					duration: 0,
					translateY: [0, 50],
					opacity: [1, 0],
				});
		}
		menuIsOpen = false;
	}
	menuToggle.on('click', function (e) {
		e.preventDefault();
		if (!menuIsOpen) {
			_open_menu();
		} else {
			_close_menu();
		}
	});
	menuOverlay.on('click', function (e) {
		e.preventDefault();
		_close_menu();
	});
	onepageLinks.on('click', function (e) {
		_close_menu();
	});
	$(document).on('keyup', function (e) {
		if (e.keyCode === 27) {
			_close_menu();
		}
	});
})(jQuery);
/***********************************************
 * RICHARD: JARALLAX
 ***********************************************/
(function ($) {
    'use strict';

    // jarallax
    if (typeof $.fn.jarallax !== 'undefined') {
        $('.jarallax').jarallax({
            speed: 0.75,
        });
    }
})(jQuery);

/***********************************************
 * RICHARD: OTHER SCRIPTS
 ***********************************************/
(function ($) {
    'use strict';

    // Fitvids
    if (typeof $.fn.fitVids !== 'undefined') {
        PTJS.body.fitVids({
            ignore: 'object',
        });
    }

    // Widget menu
    if (typeof $.fn.superclick !== 'undefined') {
        $('.widget_pages > ul, .widget_nav_menu ul.menu').superclick({
            delay: 300,
            cssArrows: false,
            animation: {
                opacity: 'show',
                height: 'show',
            },
            animationOut: {
                opacity: 'hide',
                height: 'hide',
            },
        });
    }

    // Fast click
    if (typeof FastClick === 'function') {
        FastClick.attach(document.body);
    }

    //Aos
    AOS.init({
        easing: 'ease-in-out-sine',
        duration: 700,
        disable: function () {
            return $('.disable-aos').length ? true : false;
        },
    });

    $(document).on('ready', function (e) {
        var jarallax = $('.masthead');
        var height = $('.elementor-element');

        if (height.hasClass('same-height')) {
            var final = $('.elementor-element.same-height').height();
            jarallax.css('height', final);
        }
    });
})(jQuery);

/***********************************************
 * RICHARD: PRELOADER
 ***********************************************/
(function ($) {
    'use strict';
    // check if plugin defined
    if (typeof $.fn.animsition == 'undefined') {
        return;
    }
    var animsitionClass = $('.animsition');
    animsitionClass.animsition({
        inDuration: 500,
        outDuration: 500,
        linkElement: 'a:not([target="_blank"]):not([href^="#"]):not([rel="nofollow"]):not([href~="#"]):not([href^=mailto]):not([href^=tel]):not(.sf-with-ul):not([aria-current="page"])',
        loadingClass: 'animsition-loading-2',
        loadingInner: '<div class="spinner"><span class="double-bounce-one"></span><span class="double-bounce-two"></span></div>',
    });
    animsitionClass.on('animsition.inEnd', function () {
        PTJS.window.trigger('ptf.preloader_done');
        PTJS.html.addClass('vlt-is-page-loaded');
    });
})(jQuery);
/***********************************************
 * WIDGET: CONTACT FORM 7
 ***********************************************/
(function ($) {
    'use strict';

    var PaulThemesContactForm7 = function ($scope, $) {
        // Remove unused tags
        $('.wpcf7-form').find('p').contents().unwrap();
        $('.wpcf7-form').find('p, br').remove();
    };

    PTJS.window.on('elementor/frontend/init', function () {
        elementorFrontend.hooks.addAction(
            'frontend/element_ready/vlt-contact-form-7.default',
            PaulThemesContactForm7
        );
    });
})(jQuery);

/***********************************************
 * WIDGET: FULLPAGE SLIDER
 ***********************************************/
(function ($) {
    'use strict';

    var PaulThemesFullpageSlider = function ($scope, $) {
        // check if plugin defined
        if (typeof anime == 'undefined') {
            return;
        }

        var el = $scope.find('.vlt-fullpage-slider'),
            loop_top = el.data('loop-top') ? true : false,
            loop_bottom = el.data('loop-bottom') ? true : false,
            speed = el.data('speed') || 280,
            dots = el.data('dots') ? {} : false,
            anchors = [];

        if (typeof $.fn.pagepiling == 'undefined') {
            return;
        }

        PTJS.body.css('overflow', 'hidden');
        PTJS.html.css('overflow', 'hidden');

        el.find('[data-anchor]').each(function () {
            anchors.push($(this).data('anchor'));
        });

        el.pagepiling({
            menu: '.sf-menu',
            scrollingSpeed: speed,
            loopTop: loop_top,
            loopBottom: loop_bottom,
            anchors: anchors,
            verticalCentered: true,
            sectionSelector: '.vlt-section',
            navigation: dots,
            afterLoad: function (anchorLink, index) {
                bodyWhiteColor();
            },
        });

        function bodyWhiteColor() {
            if (el.find('.pp-section.active').hasClass('white-color')) {
                $('body').addClass('vlt-navbar--white');
            } else {
                $('body').removeClass('vlt-navbar--white');
            }
        }
        bodyWhiteColor();

        $('#pp-nav')
            .remove()
            .appendTo(el)
            .addClass('vlt-right-boxed hidden-xs');

        $('.vlt-resume')
            .on('mouseover', function () {
                $(this)
                    .parents('.vlt-section')
                    .find('.has-mask')
                    .addClass('hide');
            })
            .on('mouseleave', function () {
                $(this)
                    .parents('.vlt-section')
                    .find('.has-mask')
                    .removeClass('hide');
            });

        $('.vlt-project-detail').eq(0).addClass('is-active');
        $('.vlt-section__background-changer .vlt-section__background')
            .eq(0)
            .addClass('is-active');

        $('.vlt-project-detail').on('mouseover', function () {
            var index = $(this).index();
            $('.vlt-project-detail').removeClass('is-active');
            $(this).addClass('is-active');
            $('.vlt-section__background-changer .vlt-section__background')
                .removeClass('is-active')
                .eq(index)
                .addClass('is-active');
        });
    };

    PTJS.window.on('elementor/frontend/init', function () {
        elementorFrontend.hooks.addAction(
            'frontend/element_ready/vlt-fullpage-slider.default',
            PaulThemesFullpageSlider
        );
    });
})(jQuery);

/***********************************************
 * WIDGET: PROJECT SLIDER
 ***********************************************/
(function ($) {
    'use strict';

    var PaulThemesProjectSlider = function ($scope, $) {
        // check if plugin defined
        if (typeof $.fn.owlCarousel == 'undefined') {
            return;
        }

        var el = $scope.find('.vlt-slider-project'),
            loop = el.data('loop') || false,
            nav = el.data('nav') || false,
            dots = el.data('dots') || false,
            count = el.data('count') || 1;

        el.owlCarousel({
            items: 1,
            responsive: {
                0: {
                    items: 1,
                },
                720: {
                    items: 1,
                },
                1280: {
                    items: count,
                },
            },
            responsiveRefreshRate: 0,
            loop: loop,
            nav: nav,
            dots: dots,
        });
    };

    PTJS.window.on('elementor/frontend/init', function () {
        elementorFrontend.hooks.addAction(
            'frontend/element_ready/vlt-slider-projects.default',
            PaulThemesProjectSlider
        );
    });
})(jQuery);

/***********************************************
 * WIDGET: TESTIMONIAL SLIDER
 ***********************************************/
(function ($) {
    'use strict';

    var PaulThemesTestimonialSlider = function ($scope, $) {
        // check if plugin defined
        if (typeof $.fn.owlCarousel == 'undefined') {
            return;
        }

        var el = $scope.find('.vlt-testimonial'),
            loop = el.data('loop') || false,
            count = el.data('count') || 2;

        el.owlCarousel({
            responsive: {
                0: {
                    items: 1,
                },
                720: {
                    items: 1,
                },
                1280: {
                    items: count,
                },
            },
            responsiveRefreshRate: 0,
            loop: loop,
            nav: false,
            navText: [],
            dots: true,
        });
    };

    PTJS.window.on('elementor/frontend/init', function () {
        elementorFrontend.hooks.addAction(
            'frontend/element_ready/vlt-testimonial-slider.default',
            PaulThemesTestimonialSlider
        );
    });
})(jQuery);
