<?php

/**
 * @author: PaulThemes
 * @version: 1.0
 */

/**
 * ACF in Admin Panel
 */
if ( ! function_exists( 'richard_acf_in_admin_panel' ) ) {
	function richard_acf_in_admin_panel() {
		return richard_get_theme_mod( 'acf_show_admin_panel' ) == 'show' ? true : false;
	}
}
add_filter( 'richard/acf_show_admin_panel', 'richard_acf_in_admin_panel' );

/**
 * Add body class
 */
if ( ! function_exists( 'richard_add_body_class' ) ) {
	function richard_add_body_class( $classes ) {
		$classes[] = '';
		if ( ! wp_is_mobile() ) {
			$classes[] = 'no-mobile';
		} else {
			$classes[] = 'is-mobile';
		}
		return $classes;
	}
}
add_filter( 'body_class', 'richard_add_body_class' );

/**
 * Add html class
 */
if ( ! function_exists( 'richard_add_html_class' ) ) {
	function richard_add_html_class( $classes = '' ) {
		return apply_filters( 'richard/add_html_class', richard_sanitize_class( $classes ) );
	}
}

/**
 * Get post password form
 */
if ( ! function_exists( 'richard_get_post_password_form' ) ) {
	function richard_get_post_password_form() {
		global $post;
		$label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );
		$output = '<form class="vlt-post-password-form" action="' . esc_url( site_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" method="post">';
		$output .= '<i class="ion-ios-locked-outline"></i>';
		$output .= '<h4>' . esc_html__( 'Password Protected', 'richard' ) . '</h4>';
		$output .= '<p>' . esc_html__( 'This content is restricted access, please type the password below and get access.', 'richard' ) . '</p>';
		$output .= '<div class="vlt-form-group">';
		$output .= '<input name="post_password" id="' . $label . '" type="password" size="20" placeholder="' . esc_attr__( 'Password:' , 'richard' ) . '">';
		$output .= '</div>';
		$output .= '<button class="vlt-btn vlt-btn--primary w-100">' . esc_html__( 'Get Access' , 'richard' ) . '</button>';
		$output .= '</form>';
		return apply_filters( 'richard/get_post_password_form', $output );
	}
}
add_filter( 'the_password_form', 'richard_get_post_password_form' );

/**
 * Admin logo link
 */
if ( ! function_exists( 'richard_change_admin_logo_link' ) ) {
	function richard_change_admin_logo_link() {
		return home_url( '/' );
	}
}
add_filter( 'login_headerurl', 'richard_change_admin_logo_link' );

/**
 * Comment form fields order
 */
if ( ! function_exists( 'richard_comment_form_fields' ) ) {
	function richard_comment_form_fields( $comment_fields ) {
		if ( richard_get_theme_mod( 'comment_placement' ) == 'bottom' ) {
			$keys = array_keys( $comment_fields );
			if ( 'comment' == $keys[0] ) {
				$comment_fields['comment'] = array_shift( $comment_fields );
			}
		}
		return $comment_fields;
	}
}
add_filter( 'comment_form_fields', 'richard_comment_form_fields' );

/**
 * Remove comment notes
 */
add_filter( 'comment_form_logged_in', '__return_empty_string' );

/**
 * Add comma to tag widget
 */
if ( ! function_exists( 'richard_filter_tag_cloud' ) ) {
	function richard_filter_tag_cloud( $args ) {
		$args['smallest'] = 1;
		$args['largest'] = 1;
		$args['unit'] = 'rem';
		$args['orderby'] = 'count';
		$args['order'] = 'DESC';
		$args['separator']= '';
		return $args;
	}
}
add_filter( 'widget_tag_cloud_args', 'richard_filter_tag_cloud' );

/**
 * Remove more excerpt
 */
add_filter( 'excerpt_more', '__return_empty_string' );

add_filter('wpcf7_autop_or_not', '__return_false');